﻿using ConsoleApp2;
using ConsoleApp2.Options;
using ConsoleApp2.Services;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
using Serilog;

ThreadPool.SetMaxThreads(200, 200);
var host = Host.CreateApplicationBuilder();
host.Configuration.AddCommandLine(args);
host.Services.Configure<CsvOptions>(option =>
{
    option.DelimiterChar = ',';
    option.QuoteChar = '"';
    option.InputDir = "D:/Dump/MyDumper-Csv";
    option.OutputDir = "D:/DumpOutput";
    option.MaxThreads = 12;
});
host.Services.Configure<DataTransformOptions>(options =>
{
    var dbOption = new DatabaseOptions("localhost", 33306, "cferp_test_1", "root", "123456");
    options.DatabaseFilter = record => dbOption;
});
host.Services.AddLogging(builder =>
{
    builder.ClearProviders();
    builder.AddSerilog(new LoggerConfiguration().WriteTo.Console().CreateLogger());
});
host.Services.AddHostedService<CsvConversion>();
host.Services.AddHostedService<TaskMonitorService>();
host.Services.AddSingleton<TaskManager>();
host.Services.AddSingleton<DatabaseOutputService>();
host.Services.AddSingleton<DataTransformService>();
var app = host.Build();
await app.RunAsync();